@@ -2,7 +2,7 @@ package org.gcube.portlets.admin.resourcesweeper.client.async;
 
 import java.util.List;
 
-import org.gcube.portlets.admin.resourcesweeper.shared.SweeperActions;
+import org.gcube.resourcemanagement.support.shared.util.SweeperActions;
 
 import com.extjs.gxt.ui.client.data.ModelData;
 import com.google.gwt.user.client.rpc.RemoteService;
